@@ -1,4 +1,4 @@
-#include "timer.h"
+#include <slope/timer.h>
 
 namespace slope {
 
