@@ -29,12 +29,7 @@ test_that("unsupported error settings are caught", {
   x <- matrix(1, 3, 3)
   y <- double(3)
 
-  expect_error(SLOPE(x, y, family = "binomial", solver = "admm"))
-})
-
-test_that("sparse matrix and centering throws", {
-  xy <- SLOPE:::randomProblem(density = 0.1)
-  expect_error(SLOPE(xy$x, xy$y, center = TRUE))
+  expect_error(SLOPE(x, y, family = "binomial"))
 })
 
 test_that("specifying alpha estimation throws if not gaussian", {
@@ -46,45 +41,19 @@ test_that("specifying alpha estimation throws if not gaussian", {
   )
 })
 
-test_that("alpha estimation and path_length > 1 returns warning", {
-  x <- matrix(1, 3, 3)
-  y <- double(3)
-
-  expect_warning(SLOPE(x, y, alpha = "estimate", path_length = 3))
-})
-
 test_that("SLOPE returns an error for empty `y`", {
   expect_error(SLOPE(x = NULL, y = NULL, q = 0.1), "`y` is empty")
 })
 
 
-test_that(
-  "SLOPE returns an error for `alpha='estimate'` and `family='gaussian'`",
-  {
-    expect_error(
-      SLOPE(
-        bodyfat$x,
-        bodyfat$y,
-        alpha = "estimate",
-        family = "poisson"
-      ),
-      "`alpha = 'estimate'` can only be used if `family = 'gaussian'`"
-    )
-  }
-)
-
-
-test_that(
-  "SLOPE returns an error for nonunique `alpha`",
-  {
-    expect_error(
-      SLOPE(
-        bodyfat$x,
-        bodyfat$y,
-        alpha = rep(1, 10),
-        family = "gaussian"
-      ),
-      "all values in `alpha` must be unique"
-    )
-  }
-)
+test_that("SLOPE returns an error for `alpha='estimate'` and `family='gaussian'`", {
+  expect_error(
+    SLOPE(
+      bodyfat$x,
+      bodyfat$y,
+      alpha = "estimate",
+      family = "poisson"
+    ),
+    "`alpha = 'estimate'` can only be used if `family = 'gaussian'`"
+  )
+})
