@@ -11,7 +11,9 @@ test_that("unregularized logistic regression matches output from glm()", {
   df <- data.frame(y = y, x1 = x1, x2 = x2)
   glm_fit <- glm(y ~ x1 + x2 + x3, data = df, family = "binomial")
 
-  g_model <- SLOPE(cbind(x1, x2, x3), y,
+  g_model <- SLOPE(
+    cbind(x1, x2, x3),
+    y,
     family = "binomial",
     diagnostics = TRUE,
     alpha = 1e-7
@@ -33,7 +35,6 @@ test_that("regularized slope logistic regression picks out correct features", {
   k <- 3
 
   x <- matrix(rnorm(p * n), n, p)
-  # x <- scale(x)
   beta <- double(p)
   nz <- sample(p, k)
 
@@ -47,3 +48,20 @@ test_that("regularized slope logistic regression picks out correct features", {
 
   expect_setequal(nz, which(slope_fit$nonzeros[[1]]))
 })
+
+test_that("logistic regression works on the glioma dataset", {
+  set.seed(825)
+
+  glioma_fit <- SLOPE(
+    x = glioma$x,
+    y = glioma$y,
+    family = "binomial",
+    alpha = 1e-2
+  )
+
+  y_hat <- predict(glioma_fit, glioma$x, type = "class")
+
+  accuracy <- mean(y_hat == glioma$y)
+
+  expect_equal(accuracy, 0.975, tolerance = 1e-1)
+})
