@@ -8,11 +8,11 @@ test_that("output from unregularized poisson model matches glm", {
 
     x <- scale(x)
 
-    SLOPE_fit <- SLOPE(
+    slope_fit <- SLOPE(
       x,
       y,
       family = "poisson",
-      alpha = 1e-8,
+      alpha = 1e-5,
       intercept = intercept,
       center = FALSE,
       scale = "none"
@@ -24,7 +24,7 @@ test_that("output from unregularized poisson model matches glm", {
       glm(y ~ 0 + ., data = data.frame(y = y, x), family = "poisson")
     }
 
-    expect_equivalent(coef(glm_fit), coef(SLOPE_fit), tol = 1e-5)
+    expect_equivalent(coef(glm_fit), as.matrix(coef(slope_fit)), tol = 1e-4)
   }
 })
 
@@ -40,22 +40,33 @@ test_that("SLOPE reproduces lasso fit when all lambda are equal", {
   n <- nrow(x)
   p <- ncol(x)
 
-  alpha <- 1
+  alpha <- 0.01
 
-  gnt_fit <- glmnet::glmnet(x, y,
-    family = "poisson",
-    lambda = alpha,
-    standardize = FALSE
-  )
-  gnt_coef <- as.vector(coef(gnt_fit))
+  coef_ref <-
+    c(
+      -0.075761257437997,
+      -0.0397870591523659,
+      0.179401937344632,
+      0.0719298289970407,
+      -0.143050053903786,
+      0.0119708915618286,
+      -0.0152132541332644,
+      0.0299541615757605,
+      -0.0557280347240528,
+      -0.0502826103600737,
+      -0.0405067293862495
+    )
 
-  SLOPE_fit <- SLOPE(x, y,
+  slope_fit <- SLOPE(
+    x,
+    y,
     family = "poisson",
     alpha = alpha,
     lambda = rep(1, p),
     scale = "none",
-    center = FALSE
+    center = FALSE,
+    tol = 1e-6
   )
 
-  expect_equivalent(gnt_coef, coef(SLOPE_fit), tol = 1e-3)
+  expect_equivalent(coef_ref, as.matrix(coef(slope_fit)), tol = 1e-3)
 })
